%global srcname aiozmq
%global forgeurl https://github.com/aio-libs/%{srcname}

# Use pytest instead of upstream’s own test runner script? This may provide
# better diagnostics when something is going wrong.
%bcond_with pytest

Name:           python-%{srcname}
Version:        0.9.0
%forgemeta
Release:        1%{?dist}
Summary:        ZeroMQ integration with asyncio

License:        BSD
URL:            https://%{srcname}.readthedocs.org
Source0:        %{forgesource}

# Downstream man pages
Source10:       %{srcname}-proxy.1
Source11:       %{srcname}-proxy-queue.1
Source12:       %{srcname}-proxy-forwarder.1
Source13:       %{srcname}-proxy-streamer.1
Source14:       %{srcname}-proxy-monitor.1

# https://github.com/aio-libs/aiozmq/pull/171
Patch0:         %{srcname}-0.9.0-pr171-python3.10.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros

# Extra BR’s for testing
# tests_require in setup.py:
BuildRequires:  python3dist(msgpack) >= 0.5.0
%if %{with pytest}
BuildRequires:  python3dist(pytest)
%endif

# Extra BR’s for docs
BuildRequires:  make
# Selected entries from requirements.txt (strict version pins loosened to allow
# later versions):
# sphinx==1.7.5
BuildRequires:  python3dist(sphinx) >= 1.7.5
# sphinxcontrib-spelling==4.1.0
BuildRequires:  python3dist(sphinxcontrib-spelling) >= 4.1.0
# readthedocs-sphinx-ext==0.5.12
BuildRequires:  python3dist(readthedocs-sphinx-ext) >= 0.5.12

%global common_description %{expand:
asyncio (PEP 3156) support for ZeroMQ, a messaging library.
Features:
 · Implements create_zmq_connection() coroutine for making 0MQ connections.
 · Provides ZmqTransport and ZmqProtocol
 · Provides RPC Request-Reply, Push-Pull and Publish-Subscribe patterns for
   remote calls.}

%description %{common_description}


%generate_buildrequires
%pyproject_buildrequires -x rpc


%package -n     python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %{common_description}


%pyproject_extras_subpkg -n python3-%{srcname} rpc


%package        doc
Summary:        Documentation for %{name}

%description    doc %{common_description}


%prep
%forgeautosetup
# Use local inventory in intersphinx mapping.
#
# Currently, the python-zmq package does not package its Sphinx documentation,
# so we cannot resolve intersphinx cross-references to it.
sed -r -i \
  -e 's|https://docs.python.org/3|/%{_docdir}/python3-docs/html|' \
  -e "s|'pyzmq': ('http://zeromq.github.io/pyzmq', None)||" \
    docs/conf.py


%build
%pyproject_wheel
PYTHONPATH="${PWD}" %make_build -C docs html SPHINXOPTS='%{?_smp_mflags}'
rm -vf docs/_build/html/.buildinfo


%install
%pyproject_install
%pyproject_save_files %{srcname}

install -t '%{buildroot}%{_mandir}/man1' -D -p -m 0644 \
    '%{SOURCE10}' '%{SOURCE11}' '%{SOURCE12}' '%{SOURCE13}' '%{SOURCE14}'


%check
%if %{without pytest}
PYTHONPATH=%{buildroot}%{python3_sitelib} %{__python3} ./runtests.py
%else
%pytest --ignore=tests/zmq_events_test.py
%endif


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE.txt
%{_bindir}/%{srcname}-proxy
%{_mandir}/man1/%{srcname}-proxy*.1*


%files doc
%license LICENSE.txt
%doc ACKS.txt
%doc CHANGES.txt
%doc README.rst
%doc docs/_build/html
%doc examples


%changelog
* Sat Jul 17 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.0-1
- Update to 0.9.0
- Near-total spec file rewrite
- Add -doc subpackage
- Add metapackage for “rpc” extra
- Add downstream man pages for aiozmq-proxy

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.8.0-8.20191223git4e6703c
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-7.20191223git4e6703c
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-6.20191223git4e6703c
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.8.0-5.20191223git4e6703c
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-4.20191223git4e6703c
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Jan 01 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 0.8.0-3.20191223git56065a26
- Download source directly from github
- Use macros for generating sources
- Enable tests (Thanks to zbyszek)

* Mon Dec 23 2019 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 0.8.0-2.20191223git56065a26
- Build from master branch of repo
- contains fixes for python 3.7+

* Sun Dec 22 2019 Mukundan Ragavan <nonamedotc@gmail.com> - 0.8.0-1
- Initial package.
